import random

play = 'yes'

given_numbers = []
random_numbers = []

def random_numbers():
    while play == 'yes':
        for i in range(6):
            given_numbers.append(int(input(f"podaj liczbe numer {str(i+1)} : ")))
            random_numbers.append(random.randint(1, 50))
        hitting = 0



#!/usr/bin/python
# -*- coding: utf-8 -*-

from setuptools import find_packages, setup

setup(
    name='vasalskyy',
    version='0.2.5',
    author='vasalskyy',
    author_email='vasalskyyy@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='Hello world package'
)